Please follow PyScaffold's `contribution guidelines`_,
considering the appropriate repository-related changes
(URL, issue tracker, CI service, etc...).


.. _contribution guidelines: https://pyscaffold.org/en/latest/contributing.html
